@@ -12,7 +12,7 @@
  * and other information needed for compilation.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_typepass_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/typepass.cxx,v 1.36 2006/11/01 23:54:52 wsfulton Exp $";
+char cvsroot_typepass_cxx[] = "$Id: typepass.cxx 10003 2007-10-17 21:42:11Z wsfulton $";
 
 #include "swigmod.h"
 #include "cparse.h"
@@ -171,10 +171,10 @@ class TypePass:private Dispatcher {
 		}
 		if (Strcmp(nodeType(bcls), "classforward") != 0) {
 		  Swig_error(Getfile(cls), Getline(cls), "'%s' does not have a valid base class.\n", Getattr(cls, "name"));
-		  Swig_error(Getfile(bcls), Getline(bcls), "'%s' is not a valid base class.\n", bname);
+		  Swig_error(Getfile(bcls), Getline(bcls), "'%s' is not a valid base class.\n", SwigType_namestr(bname));
 		} else {
-		  Swig_warning(WARN_TYPE_INCOMPLETE, Getfile(cls), Getline(cls), "Base class '%s' is incomplete.\n", bname);
-		  Swig_warning(WARN_TYPE_INCOMPLETE, Getfile(bcls), Getline(bcls), "Only forward declaration '%s' was found.\n", bname);
+		  Swig_warning(WARN_TYPE_INCOMPLETE, Getfile(cls), Getline(cls), "Base class '%s' is incomplete.\n", SwigType_namestr(bname));
+		  Swig_warning(WARN_TYPE_INCOMPLETE, Getfile(bcls), Getline(bcls), "Only forward declaration '%s' was found.\n", SwigType_namestr(bname));
 		  clsforward = 1;
 		}
 		bcls = 0;
@@ -184,8 +184,8 @@ class TypePass:private Dispatcher {
 		    ilist = alist = NewList();
 		  Append(ilist, bcls);
 		} else {
-		  Swig_warning(WARN_TYPE_UNDEFINED_CLASS, Getfile(cls), Getline(cls), "Base class '%s' undefined.\n", bname);
-		  Swig_warning(WARN_TYPE_UNDEFINED_CLASS, Getfile(bcls), Getline(bcls), "'%s' must be defined before it is used as a base class.\n", bname);
+		  Swig_warning(WARN_TYPE_UNDEFINED_CLASS, Getfile(cls), Getline(cls), "Base class '%s' undefined.\n", SwigType_namestr(bname));
+		  Swig_warning(WARN_TYPE_UNDEFINED_CLASS, Getfile(bcls), Getline(bcls), "'%s' must be defined before it is used as a base class.\n", SwigType_namestr(bname));
 		}
 	      }
 	    }
@@ -239,7 +239,7 @@ class TypePass:private Dispatcher {
       Symtab *st = Getattr(cls, "symtab");
       Symtab *bst = Getattr(bclass, "symtab");
       if (st == bst) {
-	Swig_warning(WARN_PARSE_REC_INHERITANCE, Getfile(cls), Getline(cls), "Recursive scope inheritance of '%s'.\n", HashGetAttr(cls, k_name));
+	Swig_warning(WARN_PARSE_REC_INHERITANCE, Getfile(cls), Getline(cls), "Recursive scope inheritance of '%s'.\n", Getattr(cls, "name"));
 	continue;
       }
       Symtab *s = Swig_symbol_current();
@@ -520,7 +520,9 @@ class TypePass:private Dispatcher {
     } else {
       if (name) {
 	Node *nn = Swig_symbol_clookup(name, n);
-	Hash *ts = Getattr(nn, "typescope");
+	Hash *ts = 0;
+	if (nn)
+	  ts = Getattr(nn, "typescope");
 	if (!ts) {
 	  SwigType_new_scope(name);
 	  SwigType_attach_symtab(Getattr(n, "symtab"));
@@ -576,6 +578,14 @@ class TypePass:private Dispatcher {
     }
     normalize_parms(Getattr(n, "parms"));
     normalize_parms(Getattr(n, "throws"));
+    if (GetFlag(n, "conversion_operator")) {
+      /* The call to the operator in the generated wrapper must be fully qualified in order to compile */
+      SwigType *name = Getattr(n, "name");
+      SwigType *qualifiedname = Swig_symbol_string_qualify(name,0);
+      Clear(name);
+      Append(name, qualifiedname);
+      Delete(qualifiedname);
+    }
 
     if (checkAttribute(n, "storage", "typedef")) {
       String *name = Getattr(n, "name");
@@ -866,12 +876,12 @@ class TypePass:private Dispatcher {
 			  String *ucode = is_void ? NewStringf("{ self->%s(", Getattr(n, "uname")) : NewStringf("{ return self->%s(", Getattr(n, "uname"));
 
 			  for (ParmList *p = parms; p;) {
-			    StringAppend(ucode, HashGetAttr(p, k_name));
+			    Append(ucode, Getattr(p, "name"));
 			    p = nextSibling(p);
 			    if (p)
-			      StringAppend(ucode, ",");
+			      Append(ucode, ",");
 			  }
-			  StringAppend(ucode, "); }");
+			  Append(ucode, "); }");
 			  Setattr(nn, "code", ucode);
 			  Delete(ucode);
 			}
