@@ -8,10 +8,9 @@
  * parse trees.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_tree_c[] = "$Header: /cvsroot/swig/SWIG/Source/Swig/tree.c,v 1.25 2006/11/01 23:54:54 wsfulton Exp $";
+char cvsroot_tree_c[] = "$Id: tree.c 9632 2007-01-03 20:58:19Z beazley $";
 
 #include "swig.h"
-#include "swigkeys.h"
 #include <stdarg.h>
 #include <assert.h>
 
@@ -147,12 +146,12 @@ void appendChild(Node *node, Node *chd) {
 }
 
 /* -----------------------------------------------------------------------------
- * preppendChild()
+ * prependChild()
  *
- * Preppends a new child to a node
+ * Prepends a new child to a node
  * ----------------------------------------------------------------------------- */
 
-void preppendChild(Node *node, Node *chd) {
+void prependChild(Node *node, Node *chd) {
   Node *fc;
 
   if (!chd)
@@ -171,17 +170,19 @@ void preppendChild(Node *node, Node *chd) {
 }
 
 /* -----------------------------------------------------------------------------
- * deleteNode()
+ * removeNode()
  *
- * Deletes a node.
+ * Removes a node from the parse tree.  Detaches it from its parent's child list.
  * ----------------------------------------------------------------------------- */
 
-void deleteNode(Node *n) {
+void removeNode(Node *n) {
   Node *parent;
   Node *prev;
   Node *next;
 
   parent = parentNode(n);
+  if (!parent) return;
+
   prev = previousSibling(n);
   next = nextSibling(n);
   if (prev) {
@@ -198,6 +199,11 @@ void deleteNode(Node *n) {
       set_lastChild(parent, prev);
     }
   }
+
+  /* Delete attributes */
+  Delattr(n,"parentNode");
+  Delattr(n,"nextSibling");
+  Delattr(n,"prevSibling");
 }
 
 /* -----------------------------------------------------------------------------
@@ -219,21 +225,6 @@ Node *copyNode(Node *n) {
   return c;
 }
 
-/* -----------------------------------------------------------------------------
- * Swig_tag_nodes()
- *
- * Tags a collection of nodes with an attribute.   Used by the parser to mark
- * subtypes with extra information.
- * ----------------------------------------------------------------------------- */
-
-void Swig_tag_nodes(Node *n, const String_or_char *attrname, DOH *value) {
-  while (n) {
-    Setattr(n, attrname, value);
-    Swig_tag_nodes(firstChild(n), attrname, value);
-    n = nextSibling(n);
-  }
-}
-
 /* -----------------------------------------------------------------------------
  * checkAttribute()
  * ----------------------------------------------------------------------------- */
@@ -257,7 +248,7 @@ int checkAttribute(Node *n, const String_or_char *name, const String_or_char *va
  * This function can be called more than once with different namespaces.
  * ----------------------------------------------------------------------------- */
 
-int Swig_require(const char *ns, Node *n, ...) {
+void Swig_require(const char *ns, Node *n, ...) {
   va_list ap;
   char *name;
   DOH *obj;
@@ -292,18 +283,16 @@ int Swig_require(const char *ns, Node *n, ...) {
 
   /* Save the view */
   {
-    String *view = Getattr(n, k_view);
+    String *view = Getattr(n, "view");
     if (view) {
       if (Strcmp(view, ns) != 0) {
 	Setattr(n, NewStringf("%s:view", ns), view);
-	Setattr(n, k_view, ns);
+	Setattr(n, "view", ns);
       }
     } else {
-      Setattr(n, k_view, ns);
+      Setattr(n, "view", ns);
     }
   }
-
-  return 1;
 }
 
 
@@ -313,7 +302,7 @@ int Swig_require(const char *ns, Node *n, ...) {
  * are saved, ie behaves as if all the attribute names were prefixed by ?.
  * ----------------------------------------------------------------------------- */
 
-int Swig_save(const char *ns, Node *n, ...) {
+void Swig_save(const char *ns, Node *n, ...) {
   va_list ap;
   char *name;
   DOH *obj;
@@ -340,18 +329,16 @@ int Swig_save(const char *ns, Node *n, ...) {
 
   /* Save the view */
   {
-    String *view = Getattr(n, k_view);
+    String *view = Getattr(n, "view");
     if (view) {
       if (Strcmp(view, ns) != 0) {
 	Setattr(n, NewStringf("%s:view", ns), view);
-	Setattr(n, k_view, ns);
+	Setattr(n, "view", ns);
       }
     } else {
-      Setattr(n, k_view, ns);
+      Setattr(n, "view", ns);
     }
   }
-
-  return 1;
 }
 
 /* -----------------------------------------------------------------------------
@@ -366,7 +353,7 @@ void Swig_restore(Node *n) {
   String *ns;
   Iterator ki;
 
-  ns = Getattr(n, k_view);
+  ns = Getattr(n, "view");
   assert(ns);
 
   l = NewList();
